@@ -6,6 +6,18 @@ class UpstreamFailedException(Exception):
     pass
 
 
+class SourceMissingException(Exception):
+    pass
+
+
+class InvalidColumnSpecification(Exception):
+    pass
+
+
+class UnknownDataTypeException(Exception):
+    pass
+
+
 class NodeExecutionException(Exception):
     pass
 
